<?php
$lang['friendlyname'] = 'FormBuilder';
$lang['field_type_DispositionEmailFromFEUProperty'] = '*Email an Benutzer mit passender FEU Benutzer-Eigenschaft';
$lang['field_type_'] = 'Feldtyp wurde nicht definiert';
$lang['field_type_CatalogerItemsField'] = 'W&auml;hlen Sie einen (oder mehrere) Cataloger-Eintr&auml;ge aus';
$lang['field_type_FieldsetEnd'] = '- Formularabschnitt (fieldset) Ende';
$lang['field_type_FieldsetStart'] = '- Formularabschnitt (fieldset) Start';
$lang['field_type_TextField'] = 'Textfeld';
$lang['field_type_HTML5NumberField'] = 'HTML5-Zahleneingabe';
$lang['field_type_HTML5EmailField'] = 'HTML5-E-Mail-Eingabe';
$lang['field_type_HTML5URLField'] = 'HTML5-URL-Eingabe';
$lang['field_type_SiteAdminField'] = 'Seitenadministator';
$lang['field_type_PasswordField'] = 'Passwort';
$lang['field_type_PasswordAgainField'] = 'Passwort-Wiederholung';
$lang['field_type_TextFieldExpandable'] = 'Textfeld (mehrfach)';
$lang['field_type_TextAreaField'] = 'Textarea';
$lang['field_type_ButtonField'] = 'Knopf';
$lang['field_type_CheckboxField'] = 'Kontrollk&auml;stchen';
$lang['field_type_CheckboxGroupField'] = 'Kontrollk&auml;stchen-Gruppe';
$lang['field_type_PulldownField'] = 'Aufklappliste';
$lang['field_type_YearPullDownField'] = 'Aufklappliste-Jahresauswahl';
$lang['field_type_MultiselectField'] = 'Mehrfachauswahl';
$lang['field_type_StatePickerField'] = 'Auswahl eines U.S.-Staates';
$lang['field_type_ProvincePickerField'] = 'Auswahl einer kanadischen Provinz';
$lang['field_type_CountryPickerField'] = 'L&auml;nderauswahl';
$lang['field_type_DatePickerField'] = 'Datumsauswahl';
$lang['field_type_TimePickerField'] = 'Zeitauswahl';
$lang['field_type_RadioGroupField'] = 'Radioknopf-Gruppe';
$lang['field_type_DispositionDirector'] = '*Ergebnisse per E-Mail an Auswahl aus dem Listenfeld senden';
$lang['field_type_DispositionFileDirector'] = '*Ergebnisse in eine Datei aus der Listenfeldauswahl speichern';
$lang['field_type_DispositionMultiselectFileDirector'] = '*Die Ergebnisse in Datei(en) aus der Mehrfachlisten-Auswahl speichern';
$lang['field_type_DispositionPageRedirector'] = '*Auf die Seite aus dem Listenfeld weiterleiten';
$lang['field_type_DispositionEmail'] = '*Ergebnisse per E-Mail an vorgegebene Adresse(n) senden';
$lang['field_type_DispositionEmailConfirmation'] = '*&Uuml;berpr&uuml;fung &uuml;ber die E-Mail-Adresse';
$lang['field_type_DispositionFromEmailAddressField'] = '*per E-Mail an &bdquo;Von&ldquo;-Adressfeld eine Kopie senden';
$lang['field_type_DispositionFile'] = '*Ergebnisse in eine Datei schreiben';
$lang['field_type_DispositionUniqueFile'] = '*Ergebnisse f&uuml;r jede Eingabe in eine eigene Datei schreiben';
$lang['field_type_DispositionDatabase'] = '*Ergebnisse in der Datenbank speichern';
$lang['field_type_DispositionFormBrowser'] = '*Ergebnisse f&uuml;r das FormBrowser-Modul Version 0.3 speichern';
$lang['field_type_DispositionUserTag'] = '*Einen benutzerdefinierten Tag mit den Ergebnissen als Parameter aufrufen';
$lang['field_type_DispositionForm'] = '*Ergebnisse an eine festgelegte Formular-Aktions enden';
$lang['field_type_DispositionDeliverToEmailAddressField'] = '*Ergebnisse per E-Mail an eine benutzerdefinierte Email-Adresse versenden';
$lang['field_type_DispositionEmailSiteAdmin'] = '*E-Mail an den CMS-Administrator';
$lang['field_type_DispositionEmailBasedFrontendFields'] = '*E-Mail-Ergebnisse, basierend auf den Feldern im Frontend';
$lang['field_type_PageBreakField'] = '-Seitenumbruch';
$lang['field_type_FileUploadField'] = 'Dateiupload';
$lang['field_type_FromEmailAddressField'] = 'E-Mail-Adresse &bdquo;Von&ldquo;';
$lang['field_type_FromEmailAddressAgainField'] = 'E-Mail-Adresse &bdquo;Von&ldquo; wiederholen';
$lang['field_type_FromEmailNameField'] = 'E-Mail &bdquo;Von&ldquo;-Name';
$lang['field_type_FromEmailSubjectField'] = 'E-Mail &bdquo;Betreff&ldquo;';
$lang['field_type_CCEmailAddressField'] = 'E-Mail-Feld &bdquo;Kopie senden an &hellip;&ldquo; (CC)';
$lang['field_type_StaticTextField'] = '-Statischer Text';
$lang['field_type_SystemLinkField'] = '-Statischer Link';
$lang['field_type_LinkField'] = '-Link (vom Benutzer einzugeben)';
$lang['field_type_HiddenField'] = '-Verstecktes Feld';
$lang['field_type_ComputedField'] = '-Berechnetes Feld';
$lang['field_type_UniqueIntegerField'] = '-Eindeutige Zahl (Seriell)';
$lang['field_type_UserTagField'] = '-Benutzerdefinierter Tag';
$lang['field_type_CompanyDirectoryField'] = '-CompanyDirectory Feld';
$lang['field_type_ModuleInterfaceField'] = '-Modulschnittstellen Feld';
$lang['field_type_CheckboxExtendedField'] = 'Kontrollk&auml;stchen (erweitert)';
$lang['validation_none'] = 'Keine &Uuml;berpr&uuml;fung';
$lang['validation_numeric'] = 'Nummerisch';
$lang['validation_integer'] = 'Ganzzahl';
$lang['validation_email_address'] = 'E-Mail-Adresse';
$lang['validation_usphone'] = 'Telefonnummer (US)';
$lang['validation_must_check'] = 'Pflichtfeld';
$lang['validation_regex_match'] = 'Entspricht dem regul&auml;ren Ausdruck';
$lang['validation_regex_nomatch'] = 'Entspricht nicht dem regul&auml;ren Ausdruck';
$lang['validation_empty'] = 'darf nicht leer sein';
$lang['required'] = 'ben&ouml;tigt';
$lang['not_required'] = 'nicht ben&ouml;tigt';
$lang['not_available'] = 'nicht verf&uuml;gbar';
$lang['error_emailfromfeuprop'] = 'Fehler in den Feldeinstellungen';
$lang['error_nofeu'] = 'Das FrontEndUsers Modul wurde nicht gefunden.  Dieses Feld hat keine Funktion.';
$lang['error_nofeudefns'] = 'Keine passende FEU Benutzer-Eigenschaft gefunden.  Dieses Feld hat keine Funktion.';
$lang['required_field_missing'] = 'F&uuml;r ein Pflichtfeld wurde kein Wert eingegeben';
$lang['please_enter_a_value'] = 'Bitte geben Sie bei &bdquo;%s&ldquo; einen Wert ein.';
$lang['please_enter_a_number'] = 'Bitte geben Sie bei &bdquo;%s&ldquo; eine Zahl ein.';
$lang['please_enter_valid'] = 'Bitte geben Sie bei &bdquo;%s&ldquo; einen g&uuml;ltigen Eintrag ein.';
$lang['please_enter_an_integer'] = 'Bitte geben Sie bei &bdquo;%s&ldquo; einen ganzzahligen Wert ein.';
$lang['please_enter_an_email'] = 'Bitte geben Sie f&uuml;r &bdquo;%s&ldquo; eine g&uuml;ltige Email-Adresse ein.';
$lang['email_address_does_not_match'] = 'Die Email-Adresse stimmt nicht mit der Eingabe in &bdquo;%s&ldquo; &uuml;berein.';
$lang['please_enter_a_phone'] = 'Bitte geben Sie bei &bdquo;%s&ldquo; eine g&uuml;ltige Telefonnummer ein.';
$lang['please_login'] = 'Bitte melden Sie sich an, um dieses Formular zu verwenden!';
$lang['not_valid_email'] = '&bdquo;%s&ldquo; scheint keine g&uuml;ltige Email-Adresse zu sein.';
$lang['please_enter_no_longer'] = 'Bitte geben Sie einen Wert ein, der nicht l&auml;nger als %s Zeichen ist.';
$lang['please_enter_at_least'] = 'Bitte geben Sie einen Wert ein, der mindestens %s Zeichen hat.';
$lang['title_list_delimiter'] = 'Zeichen, das als Trenner verwendet werden soll, wenn mehr als ein Wert als Ergebnis zur&uuml;ckgegeben wird';
$lang['you_need_permission'] = 'Sie ben&ouml;tigen die Berechtigung &bdquo;%s&ldquo;, um diese Aktion auszuf&uuml;hren.';
$lang['lackpermission'] = 'Sie haben nicht die erforderliche Berechtigung, um auf diesen Bereich zuzugreifen.';
$lang['field_order_updated'] = 'Feldreihenfolge aktualisiert.';
$lang['form_deleted'] = 'Formular gel&ouml;scht.';
$lang['field_deleted'] = 'Feld gel&ouml;scht.';
$lang['configuration_updated'] = 'Konfigurationen aktualisiert.';
$lang['you_must_check'] = 'Bevor Sie weitermachen k&ouml;nnen, m&uuml;ssen Sie &bdquo;%s&ldquo; &uuml;berpr&uuml;fen.';
$lang['must_specify_one_destination'] = 'Sie m&uuml;ssen hier mindestens eine Zieladresse angeben!';
$lang['are_you_sure_delete_form'] = 'Wollen Sie das Formular &bdquo;%s&ldquo; wirklich l&ouml;schen?';
$lang['are_you_sure_delete_field'] = 'Wollen Sie das Feld &bdquo;%s&ldquo; wirklich l&ouml;schen?';
$lang['notice_select_type'] = 'Die erweiterten Optionen sind erst verf&uuml;gbar, wenn der Feldtyp festgelegt wurde.';
$lang['field_name_in_use'] = 'Der Feldname &bdquo;%s&ldquo; wird bereits verwendet. Bitte verwenden Sie eindeutige Feldnamen oder deaktivieren die Verwendung eindeutiger Feldnamen in der FormBuilder-Konfiguration.';
$lang['field_no_name'] = 'Die Felder m&uuml;ssen einen Namen erhalten, oder Sie deaktivieren dies in der FormBuilder-Konfiguration.';
$lang['no_field_assigned'] = 'Kein Feld zugewiesen f&uuml;r %s';
$lang['anonymous'] = 'Anonym';
$lang['abbreviation_length'] = 'L&auml;nge: %s';
$lang['boxes'] = '%s Kontrollk&auml;stchen';
$lang['options'] = '%s Optionen';
$lang['text_length'] = '%s Zeichen';
$lang['order'] = 'Reihenfolge';
$lang['unspecified'] = '(nicht angegeben)';
$lang['added'] = 'hinzugef&uuml;gt';
$lang['updated'] = 'aktualisiert';
$lang['sort_options'] = 'Optionen zur Sortierung bei der Ausgabe';
$lang['select_one'] = 'Bitte einen ausw&auml;hlen';
$lang['select_type'] = 'Einen Typ ausw&auml;hlen';
$lang['to'] = 'An';
$lang['yes'] = 'Ja';
$lang['no'] = 'Nein';
$lang['recipients'] = 'Empf&auml;nger';
$lang['fields'] = 'Felder';
$lang['file_count'] = '%s m&ouml;gliche Dateien';
$lang['destination_count'] = '%s Ziele';
$lang['save'] = 'Speichern';
$lang['add'] = 'Hinzuf&uuml;gen';
$lang['update'] = 'Aktualisieren';
$lang['save_and_continue'] = 'Speichern und Bearbeitung fortsetzen';
$lang['information'] = 'Information ';
$lang['automatic'] = 'Automatisch';
$lang['forms'] = 'Formulare';
$lang['form'] = 'Formular %s';
$lang['configuration'] = 'Konfiguration';
$lang['field_requirement_updated'] = 'Feldstatus aktualisiert.';
$lang['maximum_size'] = 'Max. Gr&ouml;&szlig;e';
$lang['permitted_extensions'] = 'Dateierweiterungen';
$lang['permitted_filetypes'] = 'Erlaubte Dateitypen';
$lang['file_too_large'] = 'Die hochgeladene Datei ist zu gro&szlig;! Die maximale Gr&ouml;&szlig;e ist:';
$lang['illegal_file_type'] = 'Dieser Dateityp darf nicht hochgeladen werden. Bitte pr&uuml;fen Sie, ob die Dateierweiterung korrekt ist.';
$lang['upload'] = 'Hochladen';
$lang['form_imported'] = 'Formular importiert.';
$lang['form_import_failed'] = 'Formular-Import fehlgeschlagen! Es ist ein Problem mit dem Format der XML-Datei aufgetreten.';
$lang['rows'] = '%s Zeilen';
$lang['cols'] = '%s Spalten';
$lang['12_hour'] = '12-Stunden-Anzeige';
$lang['24_hour'] = '24-Stunden-Anzeige';
$lang['hour'] = 'Stunde';
$lang['min'] = 'Minute ';
$lang['merid'] = 'Meridian ';
$lang['date_range'] = 'Bereich: %s &ndash; %s';
$lang['thanks'] = 'Vielen Dank! Ihre Eingaben wurden erfolgreich versandt.';
$lang['edit'] = 'Bearbeiten';
$lang['delete'] = 'L&ouml;schen';
$lang['day'] = 'Tag';
$lang['mon'] = 'Monat';
$lang['year'] = 'Jahr';
$lang['none'] = '(keine Angabe)';
$lang['css'] = 'CSS ';
$lang['uninstalled'] = 'Modul deinstalliert.';
$lang['installed'] = 'Modulversion %s installiert.';
$lang['upgraded'] = 'Modul auf Version %s aktualisiert.';
$lang['button_previous'] = '< zur&uuml;ck';
$lang['button_submit'] = 'Formular absenden';
$lang['button_continue'] = 'weiter >';
$lang['value_checked'] = 'Gepr&uuml;ft';
$lang['value_unchecked'] = 'Ungepr&uuml;ft';
$lang['tab_main'] = 'Hauptseite';
$lang['tab_symbol'] = 'Einstellungen f&uuml;r die Formularanzeige';
$lang['tab_submit'] = 'Formular-Versand';
$lang['tab_captcha'] = 'Captcha-Einstellungen';
$lang['tab_advanced'] = 'Erweiterte Einstellungen';
$lang['tab_templatelayout'] = 'Formular-Template';
$lang['tab_submissiontemplate'] = 'Best&auml;tigungs-Template';
$lang['tab_udt'] = 'Integration von benutzerdefinierten Tags';
$lang['title_feu_property'] = 'FrontEndUsers Benutzer-Eigenschaft';
$lang['info_feu_property'] = 'Es k&ouml;nnen nur bestimmte Eigenschaftstypen verwendet werden (Klappboxen, Mehrfachauswahl-Listen, etc).';
$lang['canuse_smarty'] = '<em>In diesem Feld sind auch Smarty-Variablen g&uuml;ltige Werte.<em>';
$lang['add_options'] = 'Weitere Optionen hinzuf&uuml;gen';
$lang['delete_options'] = 'Markierte Optionen l&ouml;schen';
$lang['add_checkboxes'] = 'Weitere Kontrollk&auml;stchen hinzuf&uuml;gen';
$lang['delete_checkboxes'] = 'Markierte Kontrollk&auml;stchen l&ouml;schen';
$lang['add_address'] = 'Eine weitere Adresse hinzuf&uuml;gen';
$lang['delete_address'] = 'Markierte Adressen l&ouml;schen';
$lang['add_destination'] = 'Ein weiteres Ziel hinzuf&uuml;gen';
$lang['delete_destination'] = 'Markierte Ziele l&ouml;schen';
$lang['suspected_spam'] = 'Von Ihrer IP-Adresse wurden zu viele Emails versandt. Es wurde daher vorbeugend ein Anti-Spam-Code ausgegeben.';
$lang['suspected_spam_log'] = 'Verd&auml;chtiger Spam von der IP %s wurde gestoppt.';
$lang['reorder'] = 'Felder neu ordnen';
$lang['cancel'] = 'Abbrechen';
$lang['value_set'] = 'Festgelegter Wert: %s';
$lang['help_cataloger_attribute_fields'] = 'Im folgenden finden Sie eine Liste von Attributen, die vom Cataloger-Modul verf&uuml;gbar sind.<br/>Optional k&ouml;nnen Sie g&uuml;ltige Bereiche, Werte oder mehrere Werte festlegen, die zur Filterung der Eintr&auml;ge verwendet werden k&ouml;nnen, die den Besuchern angezeigt werden.<br/>
<br/>
<strong>Bereiche:</strong><br/>
Verwenden Sie den Syntax: &quot;range: minWert to maxWert&quot;, um einen minimalen und einen maximalen Wert festzulegen.<br/>
<br/>
<strong>Mehrere Werte:</strong><br/>
 Verwenden Sie den Syntax &quot;multi: Wert1|Wert2|Wert3&quot;, um mehrere Werte f&uuml;r ein Attribut festzulegen.<br/>
<br/>
<strong>Werte der verborgenen Felder</strong><br/>
Verwenden Sie den Syntax {$fld_id}, um einen Wert f&uuml;r ein verborgenes Feld festzulegen.<br/>
<br/>';
$lang['title_textfield_label'] = 'Textfeld-Etikett';
$lang['title_show_textfield'] = 'Textfeld anzeigen?';
$lang['help_name_regex'] = 'Ein regul&auml;rer Ausdruck, der es erm&ouml;glicht, Cataloger-Eintr&auml;ge nach dem Namen zu filtern';
$lang['help_field_height'] = 'Die H&ouml;he des Feldes zur Mehrfachauswahl';
$lang['title_name_regex'] = 'Regul&auml;rer Ausdruck f&uuml;r die Namen von Cataloger-Eintr&auml;gen';
$lang['title_field_height'] = 'Feld-H&ouml;he';
$lang['title_file_path'] = 'Zielverzeichnis f&uuml;r die ausgegebenen Dateien';
$lang['title_udt_name'] = 'Benutzerdefinierter Tag';
$lang['title_uploads_destpage'] = 'Seite, auf der der Uploads-Link dargestellt werden soll';
$lang['title_uploadmodule_summary'] = 'Mit dem FormBuilder-Modul versandt ';
$lang['title_uploads_category'] = 'Uploads-Kategorie';
$lang['title_sendto_uploads'] = 'Diese Datei an das Uploads-Modul &uuml;bergeben';
$lang['title_allow_overwrite'] = 'K&ouml;nnen Uploads vorhandene Dateien &uuml;berschreiben?';
$lang['title_allow_overwrite_long'] = 'K&ouml;nnen Uploads bereits vorhandene Dateien mit dem gleichen Dateinamen &uuml;berschreiben?';
$lang['overwrite'] = 'Erm&ouml;glicht &Uuml;berschreiben';
$lang['nooverwrite'] = 'Kein &Uuml;berschreiben';
$lang['file_already_exists'] = 'Datei %s existiert bereits und kann nicht &uuml;berschrieben werden.';
$lang['title_file_rename'] = 'Dateinamenvorlage';
$lang['original_file_extension'] = 'Original Dateierweiterung (umfasst den &quot;.&quot;)';
$lang['title_suppress_filename'] = 'Unterdr&uuml;ckt Dateinamen in E-Mails und Formularen die der Endbenutzer sieht';
$lang['title_suppress_attachment'] = 'Datei darf nicht an Emails angeh&auml;ngt werden';
$lang['file_rename_help'] = 'Eine Vorlage f&uuml;r den neuen Dateinamen der nach dem Upload vergeben wird. Lassen Sie dieses Feld leer, um den Originaldateinamen beizubehalten.';
$lang['title_legend'] = 'Legende';
$lang['title_maximum_length'] = 'Maximale L&auml;nge';
$lang['title_checkbox_label'] = 'Beschriftung des Kontrollk&auml;stchens';
$lang['title_radio_label'] = 'Beschriftung des Optionsfeldes';
$lang['title_checked_value'] = 'Wert nach erfolgter Aktivierung';
$lang['title_unchecked_value'] = 'Wert ohne erfolgte Aktivierung';
$lang['title_checkbox_details'] = 'Details zur Kontrollk&auml;stchen-Gruppe';
$lang['title_delete'] = 'L&ouml;schen?';
$lang['title_select_one_message'] = 'Text f&uuml;r &bdquo;Bitte ausw&auml;hlen&ldquo;';
$lang['title_selection_value'] = 'Auswahl Wert';
$lang['title_selection_displayname'] = 'Auswahl des angezeigten Namens';
$lang['title_selection_subject'] = 'Auswahl des &bdquo;Betreffs&ldquo;';
$lang['title_select_default_country'] = 'Standardauswahl';
$lang['title_select_default_state'] = 'Standardauswahl';
$lang['title_select_default_province'] = 'Standardauswahl';
$lang['title_option_name'] = 'Name der Option';
$lang['title_option_value'] = '&Uuml;bermittelter Wert';
$lang['title_pulldown_details'] = 'Listenfeld-Optionen';
$lang['title_multiselect_details'] = 'Optionen zur Mehrfachauswahl';
$lang['title_destination_address'] = 'Ziel-Email-Adresse';
$lang['title_destination_filename'] = 'Name der Zieldatei';
$lang['title_email_from_name'] = '&bdquo;Von (Name)&ldquo; der Email';
$lang['title_relaxed_email_regex'] = 'Lockere Email-&Uuml;berpr&uuml;fung verwenden';
$lang['title_relaxed_regex_long'] = 'Verwendet eine lockere &Uuml;berpr&uuml;fung der Email (erlaubt z. Bsp. &bdquo;x@y&ldquo; anstatt des erforderlichen &bdquo;x@y.de&ldquo;)';
$lang['title_email_from_address'] = '&bdquo;Von (Email-Adresse)&ldquo; der Email';
$lang['title_email_encoding'] = 'Zeichenkodierung der Email';
$lang['title_director_details'] = 'Listenfeldbasierte Email-Details';
$lang['title_file_name'] = 'Dateiname';
$lang['title_email_subject'] = 'Betreff-Zeile der Email';
$lang['title_form_name'] = 'Formularname';
$lang['title_form_status'] = 'Formularstatus';
$lang['title_ready_for_deployment'] = 'Einsatzbereit';
$lang['title_not_ready1'] = 'Nicht einsatzbereit';
$lang['title_redirect_page'] = 'Seite, auf die nach dem Versand gesprungen werden soll';
$lang['title_not_ready2'] = 'Bitte f&uuml;gen Sie ein Feld hinzu, mit dem die Benutzereingaben verarbeitet werden. Sie k&ouml;nnen';
$lang['title_not_ready_link'] = 'diese Tastenkombination verwenden,';
$lang['title_form_alias'] = 'Formular-Alias';
$lang['title_field_alias_short'] = 'Alias ';
$lang['title_form_fields'] = 'Formularfelder';
$lang['title_field_id'] = 'Feld-ID';
$lang['title_show_fieldaliases'] = 'Feld-Aliase anzeigen';
$lang['title_show_fieldaliases_long'] = 'Aktivieren Sie dies, wenn beim Bearbeiten des Formulars der Feld-Alias angezeigt werden soll';
$lang['title_field_name'] = 'Feldname';
$lang['title_field_alias'] = 'Feld-Alias';
$lang['title_radiogroup_details'] = 'Details zur Optionsfeld-Gruppe';
$lang['title_field_type'] = 'Feldtyp';
$lang['title_not_ready3'] = 'um ein Feld zur Formularverarbeitung zu erstellen.';
$lang['title_add_new_form'] = 'Neues Formular hinzuf&uuml;gen';
$lang['title_show_version'] = 'Version des FormBuilder-Moduls anzeigen?';
$lang['title_show_version_long'] = 'Als Hilfe zur Fehlerbeseitigung wird die Versionsnummer des FormBuilder-Moduls in einem Kommentar eingebettet.';
$lang['title_add_new_field'] = 'Neues Feld hinzuf&uuml;gen';
$lang['title_form_submit_button'] = 'Text f&uuml;r den &quot;Absenden&quot;-Button';
$lang['title_button_text'] = 'Button-Text';
$lang['title_submit_button_safety'] = 'Soll dem Versenden-Knopf ein Javascript hinzugef&uuml;gt werden, um den mehrfachen Versand des Formulars zu verhindern?';
$lang['title_submit_button_safety_help'] = 'Sicherheitsscript hinzuf&uuml;gen';
$lang['title_form_next_button'] = 'Text f&uuml;r den &quot;Weiter&quot;-Button (f&uuml;r mehrseitige Formulare)';
$lang['title_form_prev_button'] = 'Text f&uuml;r den &quot;Zur&uuml;ck&quot;-Button (f&uuml;r mehrseitige Formulare)';
$lang['title_field_validation'] = 'Feld-&Uuml;berpr&uuml;fung';
$lang['title_field_to_validate'] = 'Zu &uuml;berpr&uuml;fendes Feld';
$lang['title_field_css_id'] = 'CSS-ID f&uuml;r dieses Feld';
$lang['title_form_css_class'] = 'CSS-Klasse f&uuml;r dieses Formular';
$lang['title_field_css_class'] = 'CSS-Klasse f&uuml;r dieses Feld';
$lang['title_form_predisplay_udt'] = 'Benutzerdefinierter Tag, der vor der Anzeige des Formulars ausgef&uuml;hrt werden soll';
$lang['title_form_predisplay_each_udt'] = 'Benutzerdefinierter Tag, der vor der Anzeige des Formulars aufgerufen wird (bei mehrseitigen Formularen wird er bei jeder einzelnen Seite des Formulars aufgerufen)';
$lang['title_form_validate_udt'] = 'Benutzerdefinierter Tag, der w&auml;hrend der Formularpr&uuml;fung aufgerufen wird';
$lang['title_form_required_symbol'] = 'Symbol zur Kennzeichnung der Pflichtfelder';
$lang['title_field_required'] = 'Pflichtfeld';
$lang['title_field_required_long'] = 'Erfordert zwingend eine Antwort in diesem Feld';
$lang['title_hide_label'] = 'Beschriftung verbergen';
$lang['title_hide_label_long'] = 'Diesen Feldnamen im Formular verbergen';
$lang['title_textarea_length'] = 'Maximale L&auml;nge des Feldinhalts (0 oder leer bedeutet ohne Limit)';
$lang['title_text'] = 'Anzuzeigender statischer Text';
$lang['title_field_regex'] = 'Regex-&Uuml;berpr&uuml;fung';
$lang['title_lines_to_show'] = 'Anzahl der anzuzeigenden Zeilen';
$lang['title_read_only'] = 'Nur lesen';
$lang['no_default'] = 'Keine Voreinstellung';
$lang['redirect_after_approval'] = 'Seite, auf die nach &Uuml;berpr&uuml;fung weitergeleitet wird';
$lang['title_regex_help'] = 'This regular expression will only be used if &quot;validation type&quot; is set to a regex-related option. Include a full Perl-style regex, including the start/stop slashes and flags (z. Bsp. &quot;/image\.(\d+)/i&quot;)';
$lang['title_field_required_abbrev'] = 'Pflichtfeld';
$lang['title_hide_errors'] = 'Fehler verbergen';
$lang['title_form_displaytype'] = 'Anzeigetyp des Formulars';
$lang['title_hide_errors_long'] = 'Fehler-Meldungen vor den Benutzern verbergen.';
$lang['title_email_template'] = 'Email-Template';
$lang['title_maximum_size'] = 'Maximale Gr&ouml;&szlig;e f&uuml;r hochzuladende Dateien (kilobyte)';
$lang['title_maximum_size_long'] = 'Dieses Limit ist eine Erg&auml;nzung der Vorgaben aus der PHP- oder Server-Konfiguration.';
$lang['title_file_destination'] = 'Das Verzeichnis, in das die Dateien gespeichert werden sollen';
$lang['title_permitted_extensions'] = 'Zugelassene Datei-Endungen';
$lang['title_permitted_extensions_long'] = 'Geben Sie hier eine Aufz&auml;hlung der zugelassenen Datei-Endungen jeweils getrennt duch ein Komma ein (ohne Punkt - z.B. &quot;jpg,gif,jpeg&quot;). Leerzeichen werden ignoriert. Ohne Eintrag gelten keine Beschr&auml;nkungen.';
$lang['title_show_limitations'] = 'Beschr&auml;nkungen anzeigen?';
$lang['title_show_limitations_long'] = 'Beschr&auml;nkungen der Gr&ouml;&szlig;e und der Datei-Endungen mit dem Upload-Feld anzeigen?';
$lang['title_form_template'] = 'Template f&uuml;r die Formularanzeige';
$lang['title_page_x_of_y'] = 'Seite %s von %s';
$lang['title_no_advanced_options'] = 'Das Feld hat keine erweiterten Optionen.';
$lang['title_form_unspecified'] = 'Text, der bei ungenauen Eingaben zur&uuml;ckgegeben wird';
$lang['title_enable_fastadd_long'] = 'Das Listenfeld f&uuml;r schnelles Hinzuf&uuml;gen von Feldern in Formularen aktivieren?';
$lang['title_enable_fastadd'] = 'Das Listenfeld f&uuml;r schnelles Hinzuf&uuml;gen von Feldern aktivieren?';
$lang['title_fastadd'] = 'Schnelle Felderstellung';
$lang['title_enable_antispam_long'] = 'Wenn Sie dies aktivieren, k&ouml;nnen pro IP-Adresse maximal 10 Emails versandt werden (pro Stunde).';
$lang['title_enable_antispam'] = 'Einfachen Anti-Spam-Schutz aktivieren?';
$lang['title_show_fieldids'] = 'Feld-IDs anzeigen';
$lang['title_show_fieldids_long'] = 'Wenn Sie dieses Feld aktivieren, werden die Feld-IDs beim Bearbeiten des Formulars angezeigt';
$lang['title_xml_to_upload'] = 'Ein Formular als XML-Datei hochladen';
$lang['title_xml_upload_formname'] = 'Diesen Formularnamen verwenden';
$lang['title_import_legend'] = 'XML-Formular-Import';
$lang['title_xml_upload_formalias'] = 'Diesen Formular-Alias verwenden';
$lang['title_html_email'] = 'Eine HTML-Email erzeugen?';
$lang['title_link_autopopulate'] = 'Automatisch ver&ouml;ffentlichen?';
$lang['title_link_autopopulate_help'] = 'Automatisch mit der URL der Formularseite ver&ouml;ffentlichen? (dies &uuml;berschreibt die weiter unten benannte Seiten-Link-Option)';
$lang['title_default_link'] = 'Standard-Link-URL';
$lang['title_default_link_title'] = 'Standard-Link-Text';
$lang['title_link_to_sitepage'] = 'Link auf die Seite';
$lang['title_captcha_not_installed'] = 'Wenn Sie das Captcha-Modul installieren, k&ouml;nnen Sie &uuml;ber ein <a href="http://www.wikipedia.org/wiki/Captcha" target="_new">&quot;Captcha&quot;</a> Ihr Formular vor Spam sch&uuml;tzen. Weitere Informationen finden Sie im <a href="http://dev.cmsmadesimple.org/projects/captcha/">Captcha-Project</a>.';
$lang['title_use_captcha'] = 'Captcha verwenden, um den Formularversand zu sch&uuml;tzen?';
$lang['title_use_captcha_help'] = 'Aktivieren Sie dieses Feld, um Ihr Formular mittels <a href="http://www.wikipedia.org/wiki/Captcha" target="_blank">&quot;Captcha&quot;</a> vor Spam zu sch&uuml;tzen.';
$lang['title_user_captcha'] = 'Bitte best&auml;tigen Sie, dass Sie kein maschinelles Script sind, indem Sie die Buchstaben aus dem Bild eingeben.';
$lang['title_user_captcha_error'] = 'Text bei falsch eingegebenem Captcha';
$lang['wrong_captcha'] = 'Der eingegebene Captcha-Text war falsch.';
$lang['title_title_user_captcha'] = 'Hilfetext f&uuml;r Captcha';
$lang['title_dont_submit_unchecked'] = 'F&uuml;r nicht aktivierte Kontrollk&auml;stchen keine Werte &uuml;bermitteln';
$lang['title_dont_submit_unchecked_help'] = 'Aktivieren Sie dies, wenn nur bei aktiviertem Kontrollk&auml;stchen Werte zur&uuml;ckgegeben werden sollen.';
$lang['link_label'] = 'Beschriftung des Links';
$lang['link_destination'] = 'Ziel-URL des Links';
$lang['title_default_set'] = 'H&auml;kchen voreingestellt setzen?';
$lang['title_24_hour'] = '24-Stunden-Anzeige verwenden?';
$lang['title_before_noon'] = 'A.M.';
$lang['title_after_noon'] = 'P.M.';
$lang['title_smarty_eval'] = 'Smarty-Tags in den Feldern verarbeiten?';
$lang['title_textarea_rows'] = 'Zeilen (Hinweis: Dies kann durch CSS &uuml;berschrieben werden)';
$lang['title_textarea_cols'] = 'Spalten (Hinweis: Dies kann durch CSS &uuml;berschrieben werden)';
$lang['title_form_main'] = 'Details des Hauptformulars';
$lang['title_default_blank'] = 'Voreingestellt leer';
$lang['title_default_blank_help'] = 'Voreingestellt leer (deaktiviert die Voreinstellung f&uuml;r das heutige Datum)';
$lang['title_show_username'] = 'Den Anmelde-Namen des Benutzers anzeigen?';
$lang['title_show_userfirstname'] = 'Den Vornamen des Benutzers anzeigen?';
$lang['title_show_userlastname'] = 'Den Nachnamen des Benutzers anzeigen?';
$lang['title_restrict_to_group'] = 'Die Benutzerliste auf Benutzer der spezifizierten Gruppe beschr&auml;nken';
$lang['title_encrypt_database_data'] = 'Verschl&uuml;sseln von in der Datenbank gespeicherten Daten';
$lang['title_crypt_cert'] = 'Zertifikat f&uuml;r die Verschl&uuml;sselung von Daten';
$lang['title_encryption_keyfile'] = 'Kennwortsatz oder Pfad zu einer Datei die den Kennwortsatz enth&auml;lt. (Bei verwendung von OpenSSL ist dies der Kennwortsatz f&uuml;r den privaten Schl&uuml;ssel)';
$lang['title_encrypt_sortfields'] = 'Hash sort fields?';
$lang['title_private_key'] = 'Privater Schl&uuml;ssel f&uuml;r die Datenverschl&uuml;sselung';
$lang['title_encrypt_sortfields_help'] = 'This hashes the sort fields, but leaves the first few letters unencrypted. Cryptographically, this creates a vulnerability, but for most users it is an acceptable tradeoff between security and the ability to sort records. Sorting becomes approximate, but will remain pretty good. If you do not use this option, sort fields are stored in plaintext.';
$lang['title_encryption_functions'] = 'Verschl&uuml;sselte Speicherung nicht verf&uuml;gbar';
$lang['title_install_crypto'] = 'Bitte installieren Sie das OpenSSL Modul oder die PHP mcrypt Bibliothek wenn Sie verschl&uuml;sselte Daten in der Datenbank speichern m&ouml;chten.';
$lang['title_install_curl'] = 'Bitte pr&uuml;fen Sie ob Ihre PHP Installation CURL unterst&uuml;tzt. Siehe auch http://www.php.net/manual/de/book.curl.php';
$lang['title_mle_version'] = 'Im Mehrsprachenmodus (MLE) starten';
$lang['title_mle_version_long'] = 'Changes/support for CMSMS Multi-Language Edition fork. Do not check this if you are not running the MLE version.';
$lang['title_ensure_cert_key_match'] = 'Ensure that you select the private key that is appropriate for the certificate you are using for encryption!';
$lang['choose_crypt'] = 'Verschl&uuml;sselungsbibliothek';
$lang['title_encrypt_database_long'] = 'Check this to encrypt the stored data. This makes it more difficult (but not impossible) for hackers to view the information.';
$lang['choose_crypt_long'] = 'The options below only apply if you are using the OpenSSL Encryption library';
$lang['title_crypt_lib'] = 'Verschl&uuml;sselungsbibliothek';
$lang['openssl'] = 'OpenSSL-Bibliothek';
$lang['mcrypt'] = 'PHP mcrypt Bibliothek';
$lang['title_feu_binding'] = 'Frontend User binding';
$lang['title_install_feu'] = 'Please install the Frontend User module to connect a form and its data to a specific user';
$lang['title_feu_bind_help'] = 'Check this to lock front-end access to this form&#039;s data to the logged-in front-end user.';
$lang['title_encryption'] = 'Verschl&uuml;sselung';
$lang['title_export_form_to_udt'] = 'Export form reference to UDT as $params[&#039;FORM&#039;]?';
$lang['title_url_help'] = 'Vollst&auml;ndige URL, inklusive Protokoll und Verzeichnispfad (z.B. http://myhost.com/form_handler.cgi)';
$lang['title_url'] = 'Formular-Empf&auml;nger-URL';
$lang['title_method'] = 'Formularmethode';
$lang['title_maps_to'] = 'Map field &quot;%s&quot; to form submission variable';
$lang['title_additional'] = 'Additional submission';
$lang['title_additional_help'] = 'Anything to be appended to the submission payload, in URL-encoded form (.e.g, &quot;user=steve+jobs&amp;employee_number=1)';
$lang['title_include_in_submission'] = 'Include field in Submission';
$lang['title_date_order'] = 'Date component field order (for input)';
$lang['title_data_stored_in_fbr'] = 'Data will be stored in an XML format in the [PREFIX]_module_fb_frombrowser database table.';
$lang['error_has_no_fb_field'] = 'Error! Either the form has no form_builder disposition, or it failed to instantiate (due to memory issues?)';
$lang['help_date_order'] = 'Format: &quot;m&quot; f&uuml;r Monat, &quot;d&quot; f&uuml;r Tag, und &quot;y&quot; f&uuml;r Jahr. Trennen Sie die Werte durch Bindestriche.';
$lang['restricted_to_group'] = 'Nur in Gruppe %s';
$lang['title_show_to_user'] = 'Dem Benutzer anzeigen?';
$lang['title_use_random_generator'] = 'Verwende zuf&auml;llige Zahlen statt fest vorgegebener';
$lang['title_numbers_to_generate'] = 'Anzahl der generierten Nummern';
$lang['help_leaveempty'] = 'Dieses Feld kann leer gelassen werden';
$lang['help_variables_for_template'] = 'Variablen f&uuml;r das Template';
$lang['help_variables_for_computation'] = 'Verf&uuml;gbare Variablen';
$lang['help_php_variable_name'] = 'PHP-Variable';
$lang['help_submission_date'] = 'Versanddatum';
$lang['help_server_name'] = 'Ihr Server';
$lang['help_sub_source_ip'] = 'IP-Adresse des Formularabsenders';
$lang['help_sub_url'] = 'URL der Formularseite';
$lang['help_fb_version'] = 'FormBuilder-Version';
$lang['help_tab'] = 'Tab-Zeichen';
$lang['help_ignored_if_upload'] = '(Dieses Feld wird bei Verwendung des Uploads Moduls ignoriert)';
$lang['help_other_fields'] = 'Alternative Feldnamen k&ouml;nnen wechselweise verwendet werden (dies ist insbesondere dann n&uuml;tzlich, wenn Smarty Probleme mit Zeichen au&szlig;erhalb von ASCII 32-126 hat). <br />Wenn Sie diese dem Formular hinzuf&uuml;gen, sind weitere Felder verf&uuml;gbar.';
$lang['help_array_fields'] = 'Dies ist eine weitere Option, um via $fieldname_obj, $alias_obj oder $fld_#_obj die Feldwerte abzufragen (jedes Feld enth&auml;lt ein Objekt):<br />
<table>
<tr><td class=&quot;odd&quot;>name</td><td class=&quot;odd&quot;>Feld-name</td></tr>
<tr><td>type</td><td>Feldtyp</td></tr>
<tr><td class=&quot;odd&quot;>id</td><td class=&quot;odd&quot;>Interne Feld-ID</td></tr>
<tr><td>value</td><td>Menschen-lesbarer Wert</td></tr>
<tr><td class=&quot;odd&quot;>valueArray</td><td class=&quot;odd&quot;>Array der Feldwerte</td></tr></table>
<em>Beispiel:</em>{$fld_1_obj->name} = {$fld_1_obj->value}';
$lang['help_date_format'] = 'Informationen zur Formatierung finden Sie <a href="http://de.php.net/manual/de/function.date.php" target="_blank">in der PHP-Beschreibung</a>.';
$lang['help_variable_name'] = 'Variable ';
$lang['help_form_field'] = 'Dieses Feld enth&auml;lt';
$lang['help_rtf_file_template'] = 'Geben Sie eine Datei im FormBuilder/templates/ Ordner an. Bei Dateityp TXT wird dieses Feld ignoriert.';
$lang['help_rtf_template_type'] = 'Basic: Use the textarea below to layout the field names/values in a single block.<br />
Advanced: Specify Smarty variables in the RTF Template File as you would below, but arrange them however you like and add formatting.<br />
&nbsp;You can still use the %%HEADER%% and %%FOOTER%% sections in the RTF file.';
$lang['help_unique_file_template'] = 'For TXT, this will be immediately after the Header Template.<br />
For RTF, this will replace the %%FIELDS%% string in the template file if RTF Template Type is set to &quot;Basic&quot;.<br />
This field will be ignored if using &quot;RTF&quot; as File Type and &quot;Advanced&quot; as RTF Template Type.';
$lang['help_file_header_template'] = 'Bei TXT am Anfang der Datei plaziert. Bei RTF wird der Platzhalter %%HEADER%% in der Template-Datei ersetzt.';
$lang['help_file_footer_template'] = 'Bei TXT am Ende der Datei plaziert. Bei RTF wird der Platzhalter %%FOOTER%% in der Template-Datei ersetzt.';
$lang['link_back_to_form'] = '&laquo; Zur&uuml;ck zum Formular';
$lang['title_create_sample_template'] = 'Ein Beispiel-Template erstellen';
$lang['title_create_sample_html_template'] = 'Ein Beispiel-HTML-Template erstellen';
$lang['title_create_sample_header_template'] = 'Ein Beispiel-Header-Template erstellen';
$lang['title_create_sample_footer_template'] = 'Ein Beispiel-Footer-Template erstellen';
$lang['title_create_sample_header'] = 'Einen Beispiel-Header erstellen';
$lang['help_tab_symbol'] = 'ein Tabulator-Zeichen';
$lang['title_file_template'] = 'Vorlage f&uuml;r eine Zeile der ausgegebenen Datei';
$lang['title_file_header'] = 'Vorlage f&uuml;r den Header der ausgegebenen Datei';
$lang['title_file_footer'] = 'Vorlage f&uuml;r den Footer der ausgegebenen Datei';
$lang['title_rtf_file_template'] = 'Vorlage einer zu verwendenden RTF-Datei';
$lang['title_unique_file_template'] = 'Vorlage f&uuml;r Ausgabe';
$lang['title_file_type'] = 'Einen Dateitypen w&auml;hlen';
$lang['title_rtf_template_type'] = 'Einen RTF-Vorlagentypen w&auml;hlen';
$lang['title_confirmation_url'] = 'URL zur Best&auml;tigung des Formulars';
$lang['title_value'] = 'Wert (siehe Registerkarte Erweiterungen, wenn Sie Smarty-Tags verwenden)';
$lang['title_date_format'] = 'Datums-Format (siehe <a href="http://de.php.net/manual/de/function.date.php" target="_blank">PHP-Datumsformat</a>)';
$lang['title_use_wysiwyg'] = 'WYSIWYG-Editor f&uuml;r den Textbereich verwenden (nur in der Administration)?';
$lang['title_submit_actions'] = 'Verhalten nach dem Formular-Versand';
$lang['title_submit_labels'] = 'Beschriftung der Versand-Button';
$lang['title_sortable_field'] = 'Sortierbares Feld Nr. %s';
$lang['title_submit_help'] = 'Auf dieser Seite k&ouml;nnen Sie den Formularversand anpassen. Es wird jedoch NICHT festgelegt, wie die versandten Daten verarbeitet werden. Daf&uuml;r m&uuml;ssen Sie Ihrem Formular ein separates Feld hinzuf&uuml;gen.';
$lang['title_start_year'] = 'Beginn Jahresbereich';
$lang['title_end_year'] = 'Ende Jahresbereich';
$lang['title_default_year'] = 'Voreingestelltes Jahr';
$lang['title_default_year_help'] = '(Mit -1 wird das aktuelle Jahr als Voreinstellung verwendet)';
$lang['title_submit_action'] = 'Nachdem das Formular versandt wurde';
$lang['title_submit_response'] = 'Anzuzeigende Antwort';
$lang['title_submit_date'] = 'Datum &uuml;bermittelt';
$lang['title_approval_date'] = 'Datum gepr&uuml;ft (durch den Administrator)';
$lang['title_user_approved'] = 'Datum gepr&uuml;ft (durch den Versender)';
$lang['display_text'] = 'Versand-Vorlage anzeigen';
$lang['redirect_to_page'] = 'Weiterleiten auf die Seite';
$lang['title_submit_response_help'] = 'Dieses Template wird angezeigt, nachdem das Formular versandt wurde. Dieses Template wird nicht verwendet, um Emails zu erzeugen oder andere Formular-Optionen auszuf&uuml;hren. Falls erw&uuml;nscht, k&ouml;nnen Sie diese Templates in der &bdquo;erweiterten&ldquo; Registerkarte f&uuml;r diese Felder festlegen.';
$lang['title_destination_page'] = 'Zielseite';
$lang['title_require_fieldnames'] = 'Erfordert Feldnamen';
$lang['title_require_fieldnames_long'] = 'Soll f&uuml;r die Felder ein Name festgelegt werden?';
$lang['title_unique_fieldnames'] = 'Erfordert eindeutige Feldnamen';
$lang['title_unique_fieldnames_long'] = 'Soll f&uuml;r die Felder ein eindeutiger Name festgelegt werden?';
$lang['title_reorder_form'] = 'Felder neu ordnen';
$lang['title_load_template'] = 'Vorlage laden';
$lang['title_add_button_text'] = 'Einen Text f&uuml;r den Knopf hinzuf&uuml;gen';
$lang['title_del_button_text'] = 'Den Text f&uuml;r den Knopf l&ouml;schen';
$lang['title_field_helptext'] = 'Hilfetext, der f&uuml;r dieses Feld angezeigt wird';
$lang['title_string_or_number_eval'] = 'Variablen als Zahl oder String interpretieren';
$lang['title_order'] = 'Interpretations-Reihenfolge';
$lang['title_order_help'] = 'Wenn mehr als ein Feld berechnet werden muss, werden die Berechnung von der niedrigsten zur h&ouml;chsten Ordnungsnummer hin durchgef&uuml;hrt';
$lang['title_string_unspaced'] = 'String (keine Leerzeichen zwischen den Feldern)?';
$lang['title_compute_value'] = 'Zu berechnender Wert';
$lang['title_compute'] = 'Berechnet/PHP';
$lang['title_string'] = 'Zeichenkette';
$lang['title_numeric'] = 'Zahl';
$lang['title_inline_form'] = 'Das Formular inline anzeigen?';
$lang['title_inline_form_help'] = 'Inline bedeutet, dass das Formular den {cms_module}-Tag ersetzt, anderenfalls wird der {content}-Tag ersetzt.';
$lang['title_field_default_value'] = 'Standardwert f&uuml;r das Feld';
$lang['title_clear_default'] = 'Bei Klick auf das Feld die voreingestellten Werte entfernen?';
$lang['title_clear_default_help'] = 'Aktivieren Sie dieses Feld, wenn der voreingestellte Wert bei Klick auf das Feld entfernt werden soll. Da daf&uuml;r JavaScript verwendet wird, tritt ein Fehler auf, wenn Sie in dem vorgegebenen Text einfache Anf&uuml;hrungszeichen (&quot; oder &#039;) verwenden. Verwenden sie daher typografisch korrekte Anf&uuml;hrungszeichen (&amp;rarr; http://de.wikipedia.org/wiki/Anf%C3%BChrungszeichen#Direkte_Eingabe_per_Tastatur). Ein JavaScript-Fehler kann auch bei anderen JavaScript-unfreundlichen Zeichen auftreten.';
$lang['title_remove_file_from_server'] = 'Eine hochgeladene Datei nach der Verarbeitung (E-Mail-Versand) vom Server l&ouml;schen';
$lang['title_field_javascript'] = 'JavaScript f&uuml;r das Feld';
$lang['title_field_javascript_long'] = 'Erstellt einen vollst&auml;ndigen Javascript-Aufruf, einschlie&szlig;lich des Ereignisses, auf das reagiert werden soll, z.Bsp. onclick=&quot;yourfn()&quot;';
$lang['title_submit_javascript'] = 'Javascript f&uuml;r den Formularversand';
$lang['title_submit_javascript_long'] = 'Erstellt einen vollst&auml;ndigen Javascript-Aufruf, einschlie&szlig;lich des Ereignisses, auf das reagiert werden soll, z.Bsp. onclick=&quot;yourfn()&quot;.<br />Dies funktioniert m&ouml;glicherweise nicht richtig, wenn Sie die &quot;safety script&quot;-Option verwenden.';
$lang['email_from_addr_help'] = 'W&auml;hlen Sie hier keine zuf&auml;llige Adresse &ndash; einige Provider versenden<br />keine Emails, wenn der Domainname nicht mit dem aktuellen<br />Hostnamen &uuml;bereinstimmt (verwenden Sie zum Beispiel etwas wie name@%s)';
$lang['title_switch_advanced'] = 'Ben&ouml;tigen Sie noch mehr Feldtypen?';
$lang['title_switch_basic'] = 'Zu viele verwirrende Feldtypen?';
$lang['title_switch_advanced_link'] = 'In den erweiterten Modus wechseln';
$lang['title_switch_basic_link'] = 'In den einfachen Modus wechseln';
$lang['title_file_root'] = 'Datei in folgendem Verzeichnis speichern';
$lang['title_file_root_help'] = 'F&uuml;r dieses Verzeichnis muss Ihr Webserver die Schreibberechtigung haben<br /> Setzen Sie diese bei Bedarf via chmod 777.<br />Au&szlig;erdem sollten Sie darauf achten, dass keine PHP-Verzeichnis-Beschr&auml;nkungen bestehen.';
$lang['title_newline_replacement'] = 'Zeichen, welches die Zeilenumbr&uuml;che ersetzen soll';
$lang['title_newline_replacement_help'] = 'Lassen Sie dieses Feld leer, wenn alle Zeilenumbr&uuml;che mit ausgegeben werden sollen';
$lang['title_send_usercopy'] = 'Dem Benutzer eine Kopie des Formulars schicken?';
$lang['title_send_usercopy_label'] = 'Beschriftung f&uuml;r das Kontrollk&auml;stchen (falls durch den Benutzer ausgew&auml;hlt)';
$lang['title_send_me_a_copy'] = 'Mir eine Kopie des Formulars schicken';
$lang['title_allow_subject_override'] = 'Das &Uuml;berschreiben des Betreffs erlauben?';
$lang['title_allow_subject_override_long'] = 'Damit erlauben Sie, dass der im Listenfeld festgelegte Betreff der Email &uuml;berschrieben werden kann.';
$lang['title_display_length'] = 'Anzeigel&auml;nge';
$lang['title_minimum_length'] = 'Minimale Antwortl&auml;nge';
$lang['title_hide'] = 'Eingabe verbergen';
$lang['title_hide_help'] = 'Sollen bei der Passworteingabe Symbole anstatt einfachem Text angezeigt werden?';
$lang['password_does_not_match'] = 'Das Password stimmt nicht mit %s &uuml;berein!';
$lang['back_top'] = 'Zur&uuml;ck zur FormBuilder-Hauptseite';
$lang['title_headers_to_modify'] = 'Welche Email-Header sollen diese Eingabe erhalten?';
$lang['title_blank_invalid'] = 'Leerzeichen nicht als g&uuml;ltigen Eintrag akzeptieren';
$lang['title_blank_invalid_long'] = 'Bei Pflichtfeldern muss der Benutzer alphanumerische Zeichen statt Leerzeichen eingeben.';
$lang['title_must_save_order'] = 'Sie m&uuml;ssen einen der &bdquo;Speichern&ldquo;-Kn&ouml;pfe verwenden um die neue Feldreihenfolge zu &uuml;bernehmen.';
$lang['title_html5'] = 'Im Text HTML5-Platzhalter anstatt Javascript verwenden';
$lang['title_email_cc_address'] = 'Adresse(n), an die eine Kopie gesendet werden soll. Mehrere Adressen durch Kommas trennen.';
$lang['title_use_bcc'] = 'Blindkopie senden';
$lang['title_send_using'] = 'Mail Addressing';
$lang['title_field_to_modify'] = 'Email field to add CC address';
$lang['title_modifies'] = 'Add CC to &quot;%s&quot;';
$lang['bcc_field'] = '&quot;BCC&quot; recipients';
$lang['cc_field'] = '&quot;CC&quot; recipients';
$lang['to_field'] = 'Normal (&quot;To&quot; recipients)';
$lang['bcc'] = 'Blindkopie';
$lang['cc'] = 'Kopie';
$lang['error_CompanyDirectory_module_not_available'] = 'Das CompanyDirectory-Modul ist nicht verf&uuml;gbar!';
$lang['option_never'] = 'Niemals';
$lang['option_user_choice'] = 'Dem Benutzer eine Auswahl anbieten (Kontrollk&auml;stchen)';
$lang['option_always'] = 'Immer';
$lang['option_from'] = 'E-Mail-Adresse &bdquo;Von&ldquo;';
$lang['option_reply'] = 'E-Mail-Adresse &bdquo;Antwort an&ldquo;';
$lang['option_both'] = 'Beide E-Mail-Adressen (&bdquo;Von&ldquo; &amp; &bdquo;Antwort an&ldquo;)';
$lang['option_dropdown'] = 'Aufklappmen&uuml;';
$lang['option_selectlist_single'] = 'Auswahlliste (einfach)';
$lang['option_selectlist_multiple'] = 'Auswahlliste (mehrfach)';
$lang['option_radiogroup'] = 'Radioknopf-Guppe';
$lang['title_company_field_note'] = 'Hinweis: Ausgabe im Format<br/>&quot;Firmenname&quot;=>&quot;Wert&quot;';
$lang['title_pick_categories'] = 'W&auml;hlen Sie eine Kategorie (oder mehrere)';
$lang['title_pick_fielddef'] = 'Pull a field Definition&#039;s value (single) <em>optional</em>';
$lang['title_choose_user_input'] = 'Choose User input';
$lang['title_see_also_udt'] = '(Also take a look at the Form Submission tab if you want to set a UDT for form validation)';
$lang['title_year_end_message'] = 'Endjahr';
$lang['title_field_logic'] = 'Smarty data or logic that is meant to be sent with this field';
$lang['title_field_logic_long'] = 'Can be smarty data, javascript, or some other data you wan&#039;t to sent along with this field.<br />Goes through the Smarty compiler, so remember use {literal}{/literal} tags with <script></script>';
$lang['title_field_includelabels'] = 'Labels einschliessen';
$lang['title_field_includelabels_help'] = 'Enabling this includes labels to output. example - label: value,label2: value2';
$lang['title_field_siblings'] = 'Link this field to it&#039;s sibling';
$lang['title_field_siblings_help'] = 'Dropdown lists all siblings of this field and allows you to link this field to one of it&#039;s sibling. Makes possible controlling this field with selected sibling controls.';
$lang['title_field_hidebuttons'] = 'Hide control buttons';
$lang['title_field_hidebuttons_help'] = 'Hides frontend control buttons of this field.';
$lang['title_note'] = 'Hinweis';
$lang['title_changing_triggers_reindex'] = 'Changing any of the above fields will trigger a reindex of *all* saved records, so it could take a while.';
$lang['illegal_file'] = 'Attempted upload of illegal file type (%s) from %s';
$lang['title_searchable'] = 'Make records accessible to Search Module';
$lang['title_searchable_help'] = 'Checking this will make all submitted data accessible to the Search Module. DO NOT use this if you encrypt your data -- the information gets exposed to search whether or not it is encrypted!';
$lang['uploaded_outside_webroot'] = '%s (outside web root)';
$lang['title_fbr_edit'] = 'Editable in FormBrowser Admin?';
$lang['title_active_only'] = 'Only include active users?';
$lang['error_usertag_disposition'] = 'Der benutzerdefinierte Tag hat einen Fehler zur&uuml;ckgegeben';
$lang['error_usertag'] = 'Der benutzerdefinierte Tag %s hat einen Fehler zur&uuml;ckgegeben.';
$lang['error_cataloger_module_not_available'] = '<strong>Das Cataloger-Modul scheint nicht installiert oder aktiv zu sein.</strong>';
$lang['warning'] = 'WARNUNG!';
$lang['default_template'] = 'Standard-Template';
$lang['table_left_template'] = 'Tabellen-Template, Titel links';
$lang['table_top_template'] = 'Tabellen-Template, Titel oben';
$lang['form_template_name'] = 'Template von %s';
$lang['template_are_you_sure'] = 'Wollen Sie wirklich Ihr Template mit dem ausgew&auml;hlten Template &uuml;berschreiben? (Auch, wenn Sie dies best&auml;tigen, m&uuml;ssen Sie die &Auml;nderung speichern)';
$lang['title_bad_function'] = 'Fehler beim Berechnen von &bdquo;%s&ldquo;.';
$lang['no_referrer_info'] = 'Keine Informationen &uuml;ber den HTTP_REFERER verf&uuml;gbar (wahrscheinlich aufgrund der verwendeten Email-Pr&uuml;fung)';
$lang['validation_param_error'] = 'Fehler beim &Uuml;berpr&uuml;fen der Parameter. Bitte stellen Sie sicher, dass die URL aus Ihrer Email korrekt kopiert wurde!';
$lang['validation_response_error'] = 'Fehler bei der &Uuml;berpr&uuml;fung. Bitte stellen Sie sicher, dass die URL aus Ihrer Email korrekt kopiert wurde!';
$lang['validation_no_field_error'] = 'Fehler bei der &Uuml;berpr&uuml;fung. Dieses Formular enth&auml;lt kein Feld zur &Uuml;berpr&uuml;fung der Email!';
$lang['upgrade03to04'] = 'Form Template was updated automatically as part of the version 0.3 to version 0.4 upgrade. You may need to make some fixes. If you&#039;re using the default form, simply replace this template with &quot;default&quot; using the pulldown above.';
$lang['admindesc'] = 'Hinzuf&uuml;gen, Bearbeiten und Verwalten von interaktiven Formularen';
$lang['must_specify_one_admin'] = 'Sie m&uuml;ssen einen Administrator angeben';
$lang['operators_help'] = 'If you use String evaluation, the only operation available is concatenation (+). If you use Number evaluation you have basic, very simple math (, +, -, *, /, ). If you use Computed/PHP evaluation, you can
use any function you want, but you need to quote things (substitution occurs before evaluation), e.g., substr(&#039;$fld_22&#039;,0,2).&#039;$fld_23&#039;.';
$lang['help_module_interface'] = 'Modul-Schnittstelle verwenden';
$lang['help_module_interface_long'] = '<b>This field is used as a gateway to other modules!</b>
Use it by creating your form elements in the templates of the other module(s) you wish to incorporate, and using the <strong>{$FBid}</strong> to tie it back to FormBuilder. For example, to include form options based on the Products module, create the following template in Products:<br/>
<pre>
{foreach from=$items item=entry}
	{assign var=MData value=&#039;&#039;}
	{assign var=Cd value=&#039;&#039;}
		{foreach from=$FBvalue item=MData}
			{assign var=MData value=&#039;::&#039;|explode:$MData}
			{if $MData[1]==$entry->id}
				{assign var=Cd value=&#039; checked=&quot;checked&quot;&#039;}
			{/if}
		{/foreach}
	<div class=&quot;ProductDirectoryItem&quot;>
		<input type=&quot;checkbox&quot; value=&quot;{$entry->price}::{$entry->id}&quot; name=&quot;{$FBid}[]&quot; {$Cd} />{$entry->product_name} ({$entry->weight}{$weight_units}) &pound;{$entry->price}    
	</div>
{/foreach}
</pre>
<br/>
where in the input below you put something like <strong>{Products category=&quot;cat&quot; summarytemplate=&quot;Your_FB_template&quot;}</strong>';
$lang['title_add_tag'] = 'Ihren Tag hinzuf&uuml;gen';
$lang['date_january'] = 'Januar';
$lang['date_february'] = 'Februar';
$lang['date_march'] = 'M&auml;rz';
$lang['date_april'] = 'April ';
$lang['date_may'] = 'Mai';
$lang['date_june'] = 'Juni';
$lang['date_july'] = 'Juli';
$lang['date_august'] = 'August ';
$lang['date_september'] = 'September ';
$lang['date_october'] = 'Oktober';
$lang['date_november'] = 'November ';
$lang['date_december'] = 'Dezember';
$lang['AF'] = 'Afghanistan ';
$lang['AX'] = 'Aland Inseln';
$lang['AL'] = 'Albanien';
$lang['DZ'] = 'Algerien';
$lang['AS'] = 'Amerikanisch Samoa';
$lang['AD'] = 'Andorra ';
$lang['AO'] = 'Angola ';
$lang['AI'] = 'Anguilla ';
$lang['AQ'] = 'Antarktis';
$lang['AG'] = 'Antigua und Barbuda';
$lang['AR'] = 'Argentinien';
$lang['AM'] = 'Armenien';
$lang['AW'] = 'Aruba';
$lang['AU'] = 'Australien';
$lang['AT'] = '&Ouml;sterreich';
$lang['AZ'] = 'Aserbaidschan';
$lang['BS'] = 'Bahamas ';
$lang['BH'] = 'Bahrain ';
$lang['BB'] = 'Barbados ';
$lang['BD'] = 'Bangladesch';
$lang['BY'] = 'Wei&szlig;russland';
$lang['BE'] = 'Belgien';
$lang['BZ'] = 'Belize ';
$lang['BJ'] = 'Benin ';
$lang['BM'] = 'Bermuda ';
$lang['BT'] = 'Bhutan ';
$lang['BW'] = 'Botswana ';
$lang['BO'] = 'Bolivien';
$lang['BA'] = 'Bosnien und Herzegowina';
$lang['BV'] = 'Bouvet-Insel';
$lang['BR'] = 'Brasilien';
$lang['IO'] = 'Britisches Territorium im Indischen Ozean';
$lang['BN'] = 'Brunei Darussalam ';
$lang['BG'] = 'Bulgarien';
$lang['BF'] = 'Burkina Faso ';
$lang['BI'] = 'Burundi ';
$lang['KH'] = 'Kambodscha';
$lang['CM'] = 'Kamerun';
$lang['CA'] = 'Kanada';
$lang['CV'] = 'Kap Verde';
$lang['KY'] = 'Cayman-Inseln';
$lang['CF'] = 'Zentralafrikanische Republik';
$lang['TD'] = 'Tschad';
$lang['CL'] = 'Chile ';
$lang['CN'] = 'China ';
$lang['CX'] = 'Weihnachtsinseln';
$lang['CC'] = 'Cocos (Keeling) Inseln';
$lang['CO'] = 'Kolumbien';
$lang['KM'] = 'Comoros ';
$lang['CG'] = 'Kongo';
$lang['CD'] = 'Kongo, Demokratische Republik';
$lang['CK'] = 'Osterinseln';
$lang['CR'] = 'Costa Rica ';
$lang['CI'] = 'Ivoire (Elfenbeink&uuml;ste)';
$lang['HR'] = 'Kroatien (Hrvatska)';
$lang['CU'] = 'Kuba';
$lang['CY'] = 'Zypern';
$lang['CZ'] = 'Tschechische Republik';
$lang['DK'] = 'D&auml;nemark';
$lang['DJ'] = 'Djibouti ';
$lang['DM'] = 'Dominica ';
$lang['DO'] = 'Dominikanische Republik';
$lang['TP'] = '&Ouml;stlicher Timor';
$lang['EC'] = 'Ecuador ';
$lang['EG'] = '&Auml;gypten';
$lang['SV'] = 'El Salvador ';
$lang['GQ'] = '&Auml;quatorial Guinea';
$lang['ER'] = 'Eritrea ';
$lang['EE'] = 'Estland';
$lang['ET'] = '&Auml;thiopien';
$lang['FK'] = 'Falkland-Inseln (Malvinas)';
$lang['FO'] = 'Faroe Inseln';
$lang['FJ'] = 'Fiji ';
$lang['FI'] = 'Finnland';
$lang['FR'] = 'Frankreich';
$lang['FX'] = 'Frankreich';
$lang['GF'] = 'Guernsey ';
$lang['PF'] = 'Franz&ouml;sisch Polynesien';
$lang['TF'] = 'Franz&ouml;sische S&uuml;dliche Territorien';
$lang['MK'] = 'F.Y.R.O.M. (Mazedonien)';
$lang['GA'] = 'Gabun';
$lang['GM'] = 'Gambia ';
$lang['GE'] = 'Georgien';
$lang['DE'] = 'Deutschland';
$lang['GH'] = 'Ghana ';
$lang['GI'] = 'Gibraltar ';
$lang['GB'] = 'Gro&szlig;britannien (UK)';
$lang['GR'] = 'Griechenland';
$lang['GL'] = 'Gr&ouml;nland';
$lang['GD'] = 'Grenada ';
$lang['GP'] = 'Guadeloupe ';
$lang['GU'] = 'Guam ';
$lang['GT'] = 'Guatemala ';
$lang['GN'] = 'Guinea ';
$lang['GW'] = 'Guinea-Bissau  ';
$lang['GY'] = 'Guyana ';
$lang['HT'] = 'Haiti ';
$lang['HM'] = 'H&ouml;rten und McDonald Inseln';
$lang['HN'] = 'Honduras ';
$lang['HK'] = 'Hongkong';
$lang['HU'] = 'Ungarn';
$lang['IS'] = 'Island';
$lang['IN'] = 'Indien';
$lang['ID'] = 'Indonesien';
$lang['IR'] = 'Iran ';
$lang['IQ'] = 'Irak';
$lang['IE'] = 'Irland';
$lang['IL'] = 'Israel ';
$lang['IM'] = 'Isle of Man ';
$lang['IT'] = 'Italien';
$lang['JE'] = 'Jersey ';
$lang['JM'] = 'Jamaika';
$lang['JP'] = 'Japan ';
$lang['JO'] = 'Jordanien';
$lang['KZ'] = 'Kasachstan';
$lang['KE'] = 'Kenia';
$lang['KI'] = 'Kiribati ';
$lang['KP'] = 'Nordkorea';
$lang['KR'] = 'S&uuml;dkorea';
$lang['KW'] = 'Kuwait ';
$lang['KG'] = 'Kirgisistan';
$lang['LA'] = 'Laos ';
$lang['LV'] = 'Lettland';
$lang['LB'] = 'Libanon';
$lang['LI'] = 'Liechtenstein';
$lang['LR'] = 'Liberien';
$lang['LY'] = 'Libyen';
$lang['LS'] = 'Lesotho';
$lang['LT'] = 'Litauen';
$lang['LU'] = 'Luxemburg';
$lang['MO'] = 'Macau ';
$lang['MG'] = 'Madagaskar';
$lang['MW'] = 'Malawi ';
$lang['MY'] = 'Malaysia ';
$lang['MV'] = 'Maldiven';
$lang['ML'] = 'Mali ';
$lang['MT'] = 'Malta ';
$lang['MH'] = 'Inseln von Marschall';
$lang['MQ'] = 'Martinique ';
$lang['MR'] = 'Mauretanien';
$lang['MU'] = 'Mauritius ';
$lang['YT'] = 'Mayotte ';
$lang['MX'] = 'Mexiko';
$lang['FM'] = 'Mikronesien';
$lang['MC'] = 'Monako';
$lang['MD'] = 'Moldawien';
$lang['MA'] = 'Marokko';
$lang['MN'] = 'Mongolei';
$lang['MS'] = 'Montserrat ';
$lang['MZ'] = 'Mosambique';
$lang['MM'] = 'Myanmar ';
$lang['NA'] = 'Namibien';
$lang['NR'] = 'Nauru ';
$lang['NP'] = 'Nepal ';
$lang['NL'] = 'Niederlande';
$lang['AN'] = 'Niederl&auml;ndische Antillen';
$lang['NT'] = 'Neutrale Zone';
$lang['NC'] = 'Neukaledonien';
$lang['NZ'] = 'Neuseeland (Aotearoa)';
$lang['NI'] = 'Nikaragua';
$lang['NE'] = 'Niger ';
$lang['NG'] = 'Nigeria ';
$lang['NU'] = 'Niue ';
$lang['NF'] = 'Norfolk-Insel';
$lang['MP'] = 'N&ouml;rdliche Marianen-Inseln';
$lang['NO'] = 'Norwegen';
$lang['OM'] = 'Oman ';
$lang['PK'] = 'Pakistan ';
$lang['PW'] = 'Palau ';
$lang['PS'] = 'Pal&auml;stinensisches Territorium';
$lang['PA'] = 'Panama ';
$lang['PG'] = 'Papua-Neuguinea';
$lang['PY'] = 'Paraguay ';
$lang['PE'] = 'Peru ';
$lang['PH'] = 'Philippinen';
$lang['PN'] = 'Pitcairn ';
$lang['PL'] = 'Polen';
$lang['PT'] = 'Portugal ';
$lang['PR'] = 'Puerto Rico ';
$lang['QA'] = 'Qatar ';
$lang['RE'] = 'Reunion ';
$lang['RO'] = 'Rum&auml;nien';
$lang['RU'] = 'Russische F&ouml;deration';
$lang['RW'] = 'Ruanda';
$lang['GS'] = 'S. Georgia und S. Sandwich inseln';
$lang['KN'] = 'Saint Kitts und Nevis';
$lang['LC'] = 'Saint Lucia ';
$lang['VC'] = 'Saint Vincent &amp; Grenadinen';
$lang['WS'] = 'Samoa ';
$lang['SM'] = 'San Marino ';
$lang['ST'] = 'Sao Tome und Principe';
$lang['SA'] = 'Saudi-Arabien';
$lang['SN'] = 'Senegal ';
$lang['SC'] = 'Seychellen';
$lang['SL'] = 'Sierra Leone ';
$lang['SG'] = 'Singapur';
$lang['SI'] = 'Slowenien';
$lang['SK'] = 'Slowakische Republik';
$lang['SB'] = 'Solomon-Inseln';
$lang['SO'] = 'Somalia ';
$lang['ZA'] = 'S&uuml;dafrika';
$lang['ES'] = 'Spanien';
$lang['LK'] = 'Sri Lanka ';
$lang['SH'] = 'St. Helena ';
$lang['PM'] = 'St. Pierre und Miquelon ';
$lang['SD'] = 'Sudan ';
$lang['SR'] = 'Surinam';
$lang['SJ'] = 'Svalbard &amp; Jan Mayen Inseln';
$lang['SZ'] = 'Swaziland ';
$lang['SE'] = 'Schweden';
$lang['CH'] = 'Schweiz';
$lang['SY'] = 'Syrien';
$lang['TW'] = 'Taiwan ';
$lang['TJ'] = 'Tadschikistan';
$lang['TZ'] = 'Tansania';
$lang['TH'] = 'Thailand ';
$lang['TG'] = 'Togo ';
$lang['TK'] = 'Tokelau ';
$lang['TO'] = 'Tonga';
$lang['TT'] = 'Trinidad und Tobago';
$lang['TN'] = 'Tunesien';
$lang['TR'] = 'T&uuml;rkei';
$lang['TM'] = 'Turkmenistan ';
$lang['TC'] = 'T&uuml;rken und Caicos Inseln';
$lang['TV'] = 'Tuvalu ';
$lang['UG'] = 'Uganda ';
$lang['UA'] = 'Ukraine ';
$lang['AE'] = 'Vereinigte Arabische Emirate';
$lang['UK'] = 'Vereinigtes K&ouml;nigreich';
$lang['US'] = 'Vereinigte Staaten von Amerika';
$lang['UM'] = 'Abgelegenen kleine  US-Inseln';
$lang['UY'] = 'Uruguay ';
$lang['UZ'] = 'Usbekistan';
$lang['VU'] = 'Vanuatu ';
$lang['VA'] = 'Staat Vatikanstadt';
$lang['VE'] = 'Venezuela ';
$lang['VN'] = 'Vietnam';
$lang['VG'] = 'Jungfern-Inseln (Britisch)';
$lang['VI'] = 'Jungfern-Inseln (U.S.)';
$lang['WF'] = 'Wallis und Futuna Inseln';
$lang['EH'] = 'Westsahara';
$lang['YE'] = 'Jemen';
$lang['YU'] = 'Jugoslawien';
$lang['ZM'] = 'Sambia';
$lang['ZW'] = 'Simbabwe';
$lang['submission_error'] = 'Bei der Verarbeitung des versandten Formulars ist ein Fehler aufgetreten.';
$lang['submit_error'] = 'Fehler beim Versand: %s';
$lang['uploads_error'] = 'Fehler bei der &Uuml;bergabe der Datei an das Uploads-Modul: %s';
$lang['nouploads_error'] = 'Konnte das Uploads-Modul nicht finden';
$lang['upload_attach_error'] = 'Fehler beim Hochladen der Datei %s (tempor&auml;rer Name %s des Typs %s)';
$lang['submission_error_file_lock'] = 'Fehler. Datei konnte nicht gesperrt werden.';
$lang['unchecked_by_default'] = 'Standard: nicht ausgew&auml;hlt';
$lang['checked_by_default'] = 'Standard: ausgew&auml;hlt';
$lang['email_default_template'] = 'FormBuilder-Versand';
$lang['email_template_not_set'] = '<br/>Das Email-Template wurde noch nicht festgelegt!';
$lang['missing_cms_mailer'] = 'FormBuilder: Konnte das erforderliche CMSMailer-Modul nicht finden!';
$lang['user_approved_submission'] = 'Benutzergepr&uuml;fte &Uuml;bermittlung %s von %s';
$lang['event_info_OnFormBuilderFormSubmit'] = 'Ausf&uuml;hren, wenn ein Formular mit dem FormBuilder versandt wurde';
$lang['event_info_OnFormBuilderFormSubmitError'] = 'Ausf&uuml;hren, wenn beim Versand eines FormBuilder-Formulars ein Fehler aufgetreten ist';
$lang['event_info_OnFormBuilderFormDisplay'] = 'Ausf&uuml;hren, wenn ein FormBuilder-Formular angezeigt wurde';
$lang['event_help_OnFormBuilderFormSubmit'] = '<p>Ausf&uuml;hren, wenn ein Formular mit dem FormBuilder versandt wurde.</p>
<h4>Parameter</h4>
<ul>
<li><em>form_name</em> - der Name des Formulars (string)</li>
<li><em>form_id</em> - die interne Formulat-ID (int)</li>
<li><em>value_<name></em> - verwendet einen vorgegebenen Wert f&uuml;r ein festgelegtes Feld.</li>
</ul> ';
$lang['event_help_OnFormBuilderFormSubmitError'] = '<p>Ausf&uuml;hren, wenn beim Versand eines FormBuilder-Formulars ein Fehler aufgetreten ist</p>
<h4>Parameter</h4>
<ul>
<li><em>form_name</em> - Name des Formulars (string)</li>
<li><em>form_id</em> - die interne Formular-ID (int)</li>
<li><em>error</em> - eine Liste aller bekannte Fehler (string)</li>
</ul> ';
$lang['event_help_OnFormBuilderFormDisplay'] = '<p>Ausf&uuml;hren, wenn ein FormBuilder-Formular angezeigt wurde</p>
<h4>Parameter</h4>
<ul>
<li><em>form_name</em> - Name des Formulars (string)</li>
<li><em>form_id</em> - die interne Formular-ID (int)</li>
</ul> ';
$lang['formbuilder_params_response_id'] = 'Antwort-ID. Wird vom FormBrowser-Modul verwendet';
$lang['formbuilder_params_passed_from_tag'] = 'Standardwerte der Felder; siehe Modul-Hilfe';
$lang['formbuilder_params_field_id'] = 'Feld-ID f&uuml;r interne Operationen';
$lang['formbuilder_params_form_name'] = 'Formularname';
$lang['formbuilder_params_form_id'] = 'Formular-ID f&uuml;r interne Operationen';
$lang['formbuilder_params_general'] = 'Allgemeine Parameter f&uuml;r interne Operationen';
$lang['template_variable_help'] = '<h3>Form Template Variables</h3>
<p>You can edit it to make your form layout look any way you&#039;d like.
   To make the form work, you&#039;ll need to always include the &amp;#123;$fb_hidden} and &amp;#123;$submit}
   tags.</p>

<p>You can access your form fields either using the $fields array or by directly accessing fields by their names (e.g., &amp;#123;$myfield->input} )</p>


<p>Each field has the following attributes:</p>
<table>
<tr><th>Field</th><th>Value</th></tr>
<tr><td>field->display</td><td>1 if the field should be displayed, 0 otherwise</td></tr>
<tr><td>field->required</td><td>1 if the field is required, 0 otherwise</td></tr>
<tr><td>field->required_symbol</td><td>the symbol for required fields</td></tr>
<tr><td>field->css_class</td><td>the CSS class specified for this field</td></tr>
<tr><td>field->valid</td><td>1 if this field has passed validation, 0 otherwise</td></tr>
<tr><td>field->error</td><td>Text of the validation problem, in the event that this field did not validate</td></tr>
<tr><td>field->hide_name</td><td>1 if the field name should be hidden, 0 otherwise</td></tr>
<tr><td>field->has_label</td><td>1 if the field type has a label</td></tr>
<tr><td>field->needs_div</td><td>1 if the field needs to be wrapped in a DIV (or table row, if that&#039;s the way you swing)</td></tr>
<tr><td>field->name</td><td>the field&#039;s name</td></tr>
<tr><td>field->helptext</td><td>Optionaler Hilfetext</td></tr>
<tr><td>field->input</td><td>the field&#039;s input control (e.g., the input field itself)</td></tr>
<tr><td>field->op</td><td>a control button associated with the field if applicable (e.g., the delete button for expandable text input)</td></tr>
<tr><td>field->input_id</td><td>the ID of the field&#039;s input (useful for <label for=&quot;&quot;>)</td></tr>
<tr><td>field->type</td><td>the field&#039;s data type</td></tr>
                                
<tr><td>field->multiple_parts</td><td>1 if the field->input is actually a collection of controls</td></tr>
<tr><td>field->label_parts</td><td>1 if the collection of controls has separate labels for each control</td></tr>
</table>

<p>In certain cases, field->input is actually an array of objects rather than an input. This happens, for example, in CheckBoxGroups or RadioButtonGroups. For them, you can iterate through field->input->name and field->input->inputs.</p>
    
<p>Additional smarty variables that you can use include:</p>
<table>
<tr><th>Variable</th><th>Value</th></tr>
<tr><td>total_pages</td><td>number of pages for multi-page forms</td></tr>
<tr><td>this_page</td><td>number fo the current page for multi-page forms</td></tr>
<tr><td>title_page_x_of_y</td><td>displays &quot;page x of y&quot; for multi-page forms</td></tr>
<tr><td>css_class</td><td>CSS Class for the form</td></tr>
<tr><td>form_name</td><td>Form name</td></tr>
<tr><td>form_id</td><td>Form database ID</td></tr>
<tr><td>prev</td><td>&quot;Back&quot; button for multipart forms</td></tr>
<tr><td>submit</td><td>&quot;Continue&quot; or &quot;Submit&quot; button for multipart forms, adjusts automatically</td></tr>
</table>
<p>Dunno why you&#039;d want some of those, but there you go...</p>';
$lang['post_install'] = '<p>Stellen Sie sicher, dass die Berechtigung &bdquo;Modify Forms&ldquo; 
f&uuml;r die Benutzer gesetzt ist, welche die Feedback-Formulare administrieren werden. Sollen die Werte aus dem Formular per Email versandt werden, 
stellen Sie ebenfalls sicher, dass die Konfiguration entsprechend aktualisiert wurde.</p>
<p>ACHTUNG: W&auml;hrend der Bearbeitung darf das jeweilige Formular 
Bearbeitung nicht aktiv sein (=nutzbar f&uuml;r die G&auml;ste Ihrer Homepage). Sie sollten daher den Formular-Tag erst dann in eine aktive Inhaltsseite einf&uuml;gen, wenn das Formular komplett erstellt ist. Anderenfalls kann es zu fehlerhaften Ergebnissen kommen.</p>
<p>Hinweis: Diese Version unterst&uuml;tzt keine parallele Bearbeitung von Formularen durch mehrere Administratoren. Stellen Sie daher sicher, dass ein Formular jeweils nur von einem Administrator bearbeitet wird.</p>';
$lang['help'] = '<h3>Was macht dieses Modul?</h3>
<p>Das FormBuilder-Modul erlaubt Ihnen, Feedback-Formulare zu erstellen (logisch, es ist der Nachfolger des FeedbackForm-Moduls), erweitert um die F&auml;higkeit, eingegebene Daten auch in einer Datenbank ablegen zu k&ouml;nnen. Zusammen mit dem FormBrowser-Modul k&ouml;nnen Sie einsetzen, um einfache Datenbank-Anwendungen selbst zu erstellen.</p>
<p>Die vom FormBuilder erzeugten Formulare k&ouml;nnen in Templates 
und/oder Seiten eingef&uuml;gt werden. In die Formular k&ouml;nnen verschiedene Arten von Daten eingegeben werden. Diese Eingaben 
<p>Formularfeldern werden Namen zugewiesen. Diese Namen identifizieren Ihre Formularfelder, nicht nur auf dem Bildschirm als Bezeichnungen die dem Benutzer dienen, sondern auch in den Daten wenn sie verschickt werden. Damit wird sichergestellt dass Sie das sehen was der Nutzer eingegeben hat. <br>
Den Namen wie eine Frage zu gestalten ist eine sehr handliche Art und Weise dem Nutzer zu vermitteln was hier von ihm erwartet wird. <br>
Viele Felder haben beides, Namen und Werte. Die Namen, die dem Nutzer angezeigt werden und die Werte, das sind die die gespeichert werden wenn der Nutzer das Formular abschickt. Die Werte sind weder vom Benutzer einsehbar noch im HTML, somit ist es sicher sie f&uuml;r Email-Adressen usw. zu verwenden. </p>
<p>Einige Felder k&ouml;nnen mehrere Werte oder Namen/Werte Paare haben. Wenn Sie zuerst ein solches Feld erstellen, kann es m&ouml;glich sein, dass nicht gen&uuml;gend Eingabefelder vorhanden sind, um die Werte einzutragen. Um mehr M&ouml;glichkeiten zu erhalten Werte einzutragen, benutzen Sie den Schalter am unteren Ende der Seite f&uuml;r weitere Optionen.</p>
<p>Feldern k&ouml;nnen Validierungsregeln zugewiesen werden, welche je nach Feldtyp unterschiedlich sein k&ouml;nnen. Diese Regeln helfen sicherzustellen dass der Nutzer g&uuml;ltige Daten eingibt. Au&szlig;erdem ist es m&ouml;glich, Felder seperat mit einem &bdquo;wird ben&ouml;tigt&ldquo; zu markieren, damit wird der Nutzer sozusagen &bdquo;gezwungen&ldquo; Eingaben zu machen. </p>
<p>Feldern k&ouml;nnen auch CSS-Klassen zugewiesen werden. Es werden die Eingabefelder mit einem DIV Tag und dazugeh&ouml;riger CSS-Klasse umgeben; somit k&ouml;nnen Sie Ihr Formular selbst gestalten. Um dies effizient nutzen zu k&ouml;nnen, sollten in den Quelltext des Formulares gehen und dann Ihren CSS-Code schreiben. </p>
<ul>
<li>Standard Eingabefelder
  <ul>
    <li>Text Eingabefeld. Dies ist das Standard Eingabefeld. Sie k&ouml;nnen die L&auml;nge der eigegebenen Zeichen w&auml;hlen und verschiedene Validierungsfunktionen auf diese Feld anwenden.</li>
    <li>Textbereich. Dies ist ein gro&szlig;es formfreies Texteingabefeld.</li>
    <li>Checkbox. Das ist die Standard Checkbox.</li>
    <li>Checkbox Gruppe. Das ist eine Sammlung von Checkboxen. Der einzige Unterschied besteht darin, dass dies eine Gruppe von Checkboxen mit einem Namen ist. Weiterhin k&ouml;nnen Sie einen oder mehrere als &bdquo;wird ben&ouml;tigt&ldquo; markieren. Somit ist der Nutzer &bdquo;gezwungen&ldquo; eine oder mehrere Checkboxen dieser Gruppe auszuw&auml;hlen.</li>
    <li>Radio Button Gruppe. Das ist eine Sammlung von Radio Buttons. Nur ein Radio Button in der Gruppe kann ausgew&auml;hlt werden.</li>
    <li>Pulldown. Das ist ein Standard Pulldown Men&uuml;. Vom Konzept her gesehen das gleiche wie die Radio Button Gruppe, aber besser wenn Sie viele Auswahlm&ouml;glichkeiten haben.</li>
    <li>Mehrfachauswahl. Das ist das Mehrfachauswahl Feld. Vom Konzept her gesehen das gleiche wie die Radio Button Gruppe, aber besser wenn Sie viele Auswahlm&ouml;glichkeiten haben und die Auswahl aber begrenzen m&ouml;chten.</li>

    <li>Bundesstaat. Dies ist eine Pulldown Liste mit s&auml;mtlichen Bundesstaaten der USA.</li>
<li>L&auml;nder. Dies ist eine Pulldown Liste s&auml;mtlicher sich auf der Erde befindlichen L&auml;nder.</li>
<li>Datumsauswahl. Dies ist eine dreifach Pulldown Liste, die dem Nutzer die M&ouml;glichkeit gibt ein Datum auzuw&auml;hlen.</li>
</ul></li>

<li>Email-spezifische Eingabefelder
  <ul>
    <li>Email Von  Adress Feld. Hier k&ouml;nnen Sie Ihre Email-Adresse eingeben. Diese wird in der generierten Email im Feld Von (Mailadresse): angegeben.</li>
    <li>Email Von Name Feld. Hier k&ouml;nnen Sie Ihren Namen eingeben. Diese wird in der generierten Email im Feld Name (Absendername): angegeben.</li>

</ul></li>

<li>Kontrollfelder f&uuml;r die Anzeige<ul>
<li>Seitenumbruch - das erm&ouml;glicht Ihnen die Aufteilung Ihres Feedback-Formulars in mehrere Seiten. Die Eingaben jeder Seite werden
unabh&auml;ngig voneinander gepr&uuml;ft. Das ist insbesondere bei Online-Umfragen &auml;u&szlig;erst vorteilhaft.</li>
<li>-Statischer Text. Damit k&ouml;nnen Sie Ihrem Formular einfachen Text hinzuf&uuml;gen oder es beschriften. Dies ist f&uuml;r Ausf&uuml;llhinweise, Hilfen usw. sehr n&uuml;tzlich, insbesondere wenn Sie f&uuml;r die Anzeige des Formulars kein angepasstes Template verwenden.</li>
</ul></li>

<li>Formular &#039;Handling&#039;
  <ul>
    <li>*Email Ergebnis basierend auf dem Pulldown. Dies ist hilfreich f&uuml;r Internetseiten wo Kommentare &uuml;ber die Angelegenheit in den Betreff geschrieben werden. z.B. Bugs werden zum Entwickler gesendet, Marketing Fragen zu einer Person, Fragen zum Verkauf zu einer anderen Peson usw. Das Pulldown Men&uuml; wird mit Betreffs hinterlegt und jeder wird zu einer spezifischen Mailadresse versandt. Sie erstellen den jeweiligen Betreff wenn Sie ein solches Feld erstellen oder editieren. Wenn Sie ein solches Pulldown Men&uuml; benutzen, muss der Nutzer eine Auswahl des Betreffs w&auml;hlen um das Formular abschicken zu k&ouml;nnen. Dieses Auswahlfeld ist f&uuml;r den Nutzer sichtbar aber die Mailadressen die dahinter stehen werden weder Ihm noch im HTML angezeigt.</li>

    <li>*Email Ergebnis an Adresse(n) senden. Dies sendet die Daten an eine vorher angegebene Mailadresse. Die Mailadresse(n) k&ouml;nnen Sie angeben wenn Sie ein solches Feld generieren. Das Feld und der Name ist f&uuml;r den Nutzer nicht sichtbar. Auch nicht im Quelltext.</li>
    <li>*Daten in Datenbank speichern. Dies speichert die abgegebenen Daten in einer internen Datenbank. Diese Einstellung verwenden Sie meisten in Verbindung mit dem Modul FormBrowser.</li>
    <li>*Validierung &uuml;ber die Mailadresse. Dies ist ein sehr leistungsf&auml;higes Feld. Es stellt dem Benutzer ein vorgegebenes Eingabefeld f&uuml;r seine Mailadresse zur Verf&uuml;gung. Wenn dieser das Formular abschickt wird die &Uuml;bermittlung nicht direkt ausgef&uuml;hrt, sondern schickt dem Nutzer eine Mail mit einem codierten Link. Erst wenn dieser Link gedr&uuml;ckt wird wird das Formular validiert und die Eingaben abgeschickt.</li>
    <li>*In Datei Schreiben. Diese Option greift die Daten ab und schreibt sie in eine Textdatei. Sie k&ouml;nnen den Namen und das Dateiformat bestimmen. Diese Dateien werden in das Ausgabeverzeichnis des Modul Installations Verzeichnisses geschrieben. Vorrausgesetzt ist, dass der Server die notwendigen Schreibrechte vergeben hat.
    </ul></li></li></ul>

<h3>Templates f&uuml;r Email und einfache Dateien</h3>
<p>Man disposition types allow you to create a template for the Email that is generated, or for the way the results are written to a file. Wenn Sie selbst keine Templates erstellen wollen, wird FormBuilder die nach seiner Einsch&auml;tzung beste L&ouml;sung verwenden, die so funktioniert, wie Sie wollen oder auch nicht. Sie k&ouml;nnen jederzeit auf &bdquo;Ein Muster-Template erstellen&ldquo; klicken und dann die Ergebnisse anpassen.</p>
<p>Beachten Sie, dass neu hinzugef&uuml;gte Felder nicht mehr automatisch dem Template hinzugef&uuml;gt werden, wenn es einmal ge&auml;ndert wurde. Aus diesem Grund ist es das Beste, wenn Sie erst zum Schluss das Template f&uuml;r das Formular erstellen.</p>

<h3>Bekannte Probleme</h3>
<ul>
<li>Einige Feldtypen, die im FeedbackForm-Modul enthalten waren, sind in FormBuilder nicht implementiert. Wenn ein Bedarf f&uuml;r diese Felder vorhanden ist, werde ich sie hinzugef&uuml;gen.</li>
<li>Das FormBuilder-Modul kann gegenw&auml;rtig noch nicht auf die Daten des FrontendUsers-Moduls zugreifen. Dies ist aber geplant.</li>
<li>FormBuilder unterst&uuml;tzt gegenw&auml;rtig noch keine Pretty URLs, dies sollte jedoch kein Problem sein, da die Ausgaben Benutzerseite sehr einfach gehalten ist.</li>
</ul>

<h3>Fehlersuche</h3>
<ol><li> Als erstes sollten Sie pr&uuml;fen, ob Sie CMSms in einer Version > 1.0 verwenden.</li>
<li> Im zweiten Schritt sollten Sie die Probleme bei der Verwendung von WYSIWYG-Editoren im Abschnitt
 <em>Ein Formular einer Seite hinzuf&uuml;gen</em> lesen und verstehen.</li>
<li>Wenn Sie in einer vom FormBuilder generierten Email bestimmte Felder vermissen, &uuml;berpr&uuml;fen Sie, ob die Felder im Template enthalten sind, und stellen Sie sicher, dass Sie die fehlenden Felder auch tats&auml;chlich definiert haben. Auch wenn es nicht klar ersichtlich scheint, kann es durchaus nur ein ganz einfacher Fehler sein.</li>
<li> Versuchen Sie, auf Links und Icons zu klicken und beobachten genau, was passiert.</li>
<li> Die letzte M&ouml;glichkeit ist, mir das Problem per Email mitzuteilen oder mich im IRC-Chat anzusprechen, damit wir das Problem gemeinsam beheben.</li>
</ol> 
<p>Dies ist eine sehr fr&uuml;he Version, ein ungetestetes Beta-Release, und sehr wahrscheinlich ist es fehlerhaft. Obwohl ich alles getan habe, was ich konnte, 
um sicherzustellen, dass sich keine gr&ouml;&szlig;eren &bdquo;Wanzen&ldquo; eingeschlichen haben, musste ich w&auml;hrend des Testens feststellen, dass das Programm 
sieben Kakerlaken, zwei Ohrw&uuml;rmer, eine kleine Familie von Blattl&auml;usen und eine Wanderstabheuschrecke enthielt. Sie fra&szlig;en auch
Nachbars b&ouml;sen kleinen kl&auml;ffenden Hund, wof&uuml;r ich unendlich dankbar war.</p>
<p>Das finale Release wird Bugfixes, eine Dokumentation und unbedingte Liebe enthalten.</p>
<h3>Support</h3>
<p>Dieses Modul beinhaltet keinen kommerziellen Support. Sie k&ouml;nnen jedoch &uuml;ber die folgende Wege Hilfe zu dem Modul erhalten:</p>
<ul>
<li>F&uuml;r die letzte Version dieses Moduls, FAQs, dem Versand eines Fehlerreports oder dem Kauf kommerziellen Support besuchen sie bitte calguys Homepage unter <a href="http://techcom.dyndns.org">techcom.dyndns.org</a>.</li>
<li>Eine weitere Diskussion zu diesem Modul ist auch in den Foren von <a href="http://forum.cmsmadesimple.org">CMS Made Simple</a> zu finden.</li>
<li>Der Autor calguy1000, ist h&auml;ufig im <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a> zu finden.</li>
<li>Letztlich erreichen Sie den Autor auch &uuml;ber eine direkte Email.</li>  
</ul>
<p>Nach der GPL wird diese Software so ver&ouml;ffentlicht, wie sie ist. Bitte lesen Sie den Lizenztext f&uuml;r den vollen Haftungsausschluss.</p>
<h3>Copyright und Lizenz</h3>
<p>Copyright &copy; 2006, Samuel Goldstein <a href="mailto:sjg@cmsmodules.com"><sjg@cmsmodules.com></a>. Alle Rechte vorbehalten.</p>
<p>Dieses Modul wurde unter der <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a> ver&ouml;ffentlicht. Sie m&uuml;ssen dieser Lizenz zustimmen, bevor Sie das Modul verwenden.</p>';
?>